#!/usr/bin/env node

const yargs = require('yargs');
const Database = require('../lib/db');
const db = new Database();

yargs.command({
    command: 'create',
    builder: {
        name: { type: 'string', demandOption: true },
        age: { type: 'number', demandOption: true },
        email: { type: 'string', demandOption: true },
        password: { type: 'string', demandOption: true },
    },
    handler(argv) {
        const record = { id: Date.now().toString(), name: argv.name, age: argv.age, email: argv.email, password: argv.password };
        db.create(record);
        console.log('Record created:', record);
    }
})
    .command({
        command: 'read',
        handler() {
            const records = db.read();
            console.log(records);
        }
    })
    .command({
        command: 'update',
        builder: {
            id: { type: 'string' },
            name: { type: 'string', },
            age: { type: 'number', },
            email: { type: 'string' },
            password: { type: 'string' },
        },
        handler(argv) {
            const updatedRecord = db.update(argv.id, { name: argv.name, age: argv.age, email: argv.email, password: argv.password });
            if (updatedRecord) {
                console.log('Record updated:', updatedRecord);
            } else {
                console.log('Record not found');
            }
        }
    })
    .command({
        command: 'delete',
        builder: {
            id: { type: 'string', demandOption: true, },
        },
        handler(argv) {
            const deletedRecord = db.delete(argv.id);
            if (deletedRecord) {
                console.log('Record deleted:', deletedRecord);
            } else {
                console.log('Record not found');
            }
        }
    })

    .help().argv;
